@@ -47,7 +47,8 @@
 #include <libedata-book/e-book-backend-summary.h>
 #include "e-book-backend-mapi.h"
 
-static EBookBackendClass *e_book_backend_mapi_parent_class;
+G_DEFINE_TYPE (EBookBackendMAPI, e_book_backend_mapi, E_TYPE_BOOK_BACKEND)
+
 static gboolean enable_debug = TRUE;
 
 struct _EBookBackendMAPIPrivate
@@ -458,7 +459,7 @@ mapi_book_build_props (struct SPropValue ** value, struct SPropTagArray * SPropT
 	for (i=0; i<13; i++)
 		printf("hex %x\n", SPropTagArray->aulPropTag[i]);
 	i=0;
-	props = g_new (struct SPropValue, 50); //FIXME: Correct value tbd
+	props = g_new0 (struct SPropValue, 50); //FIXME: Correct value tbd
 	set_str_value ( E_CONTACT_FILE_AS, SPropTagArray->aulPropTag[0]);
 
 	set_str_value (E_CONTACT_FULL_NAME, PR_DISPLAY_NAME);
@@ -1790,27 +1791,3 @@ static void	e_book_backend_mapi_init (EBookBackendMAPI *backend)
 	
 	
 }
-
-
-GType	e_book_backend_mapi_get_type (void)
-{
-	static GType type = 0;
-	
-	if (! type) {
-		GTypeInfo info = {
-			sizeof (EBookBackendMAPIClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_book_backend_mapi_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (EBookBackendMAPI),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_book_backend_mapi_init
-		};
-		
-		type = g_type_register_static (E_TYPE_BOOK_BACKEND, "EBookBackendMAPI", &info, 0);
-	}
-	
-	return type;
-}
